import React, { useEffect, useState } from 'react';
import { Card, Row, Col, Table, Space, Divider, message, Image } from 'antd';
import { PageContainer } from '@ant-design/pro-layout';
import { produce } from 'immer';

import { ClubState } from '@/types/club';

import { connect, Dispatch } from 'umi';

import { Role } from '@/models/user';

import { ConnectState } from '@/models/connect';

import { role } from '@/types/role';

import { putRoleList } from '@/services/role';

import ClubModal from './ClubModal';
import { WeappItem } from '@/types';

interface IProps {
  dispatch: Dispatch;
  roleList: Role[];
}

const Club: React.FC<IProps> = ({ dispatch, roleList }) => {
  console.log(roleList, 'roleList');

  const [state, setState] = useState<ClubState>({
    loading: false,
    visable: false,
    curClub: {
      id: '',
      isForbidden: null,
      label: '',
      previousLabel: '',
      userCount: 0,
      miniProgramList: [],
    },
  });

  const { loading, visable, curClub } = state;

  console.log(loading, curClub, 'curClub');

  useEffect(() => {
    getRoleList();
  }, []);

  // 获取role列表
  const getRoleList = () => {
    dispatch({
      type: 'user/getRoleList',
      payload: {
        curPage: 1,
        passSize: 100,
      },
    });
  };

  // 打开修改弹窗
  const openModal = (records: role) => {
    console.log(records, 'records');

    setState(
      produce(state, (draft) => {
        draft.visable = true;
        draft.curClub = records;
      }),
    );
  };
  // 关闭修改弹窗
  const closeModal = () => {
    setState(
      produce(state, (draft) => {
        draft.visable = false;
      }),
    );
  };
  // 修改提交
  const onsubmit = async () => {
    setState(
      produce(state, (draft) => {
        draft.loading = true;
      }),
    );
    console.log(curClub, 'curClub');

    const { code, data } = await putRoleList(curClub);

    if (code === 0 && data === 1) {
      message.success('修改成功');
    }
    setState(
      produce(state, (draft) => {
        draft.visable = false;
        draft.loading = false;
      }),
    );

    getRoleList();
  };

  // 禁用或者启用
  const forbiddenState = async (records: role) => {
    setState(
      produce(state, (draft) => {
        draft.loading = true;
      }),
    );
    const $par = Object.assign({}, records, { isForbidden: !records.isForbidden });
    const { code, data } = await putRoleList($par);
    console.log(code, data);
    if (code === 0 && data === 1) {
      message.success($par.isForbidden ? '禁用成功' : '启用成功');
    }
    getRoleList();
    setState(
      produce(state, (draft) => {
        draft.loading = false;
      }),
    );
  };

  // 修改label
  const onChange = (e: React.ChangeEvent<HTMLInputElement>) => {
    setState(
      produce(state, (draft) => {
        draft.curClub = {
          ...curClub,
          label: e.target.value,
        };
      }),
    );
  };

  // 修改小程序列表
  const onChangeMiniProgramList = (records: WeappItem[]) => {
    setState(
      produce(state, (draft) => {
        draft.curClub = {
          ...curClub,
          miniProgramList: records,
        };
      }),
    );
  };

  return (
    <PageContainer title="俱乐部管理">
      <Card>
        <Table loading={loading} dataSource={roleList} style={{ marginTop: 20 }}>
          <Table.Column
            title="俱乐部分类"
            ellipsis
            key="previousLabel "
            dataIndex="previousLabel"
          />
          <Table.Column title="俱乐部名称" ellipsis key="label" dataIndex="label" />
          <Table.Column title="人数" ellipsis key="userCount" dataIndex="userCount" />
          <Table.Column
            title="操作"
            ellipsis
            key="action"
            dataIndex="action"
            render={(text, records: role) => (
              <Space>
                <a onClick={() => openModal(records as role)}>修改</a>
                <Divider type="vertical" />
                <a onClick={() => forbiddenState(records as role)}>
                  {!records.isForbidden ? '禁用' : '启用'}
                </a>
              </Space>
            )}
          />
        </Table>
      </Card>

      {/* 修改名称 */}
      <ClubModal
        key={curClub.id}
        visible={visable}
        curClub={curClub}
        closeModal={closeModal}
        onsubmit={onsubmit}
        onChange={onChange}
        onChangeMiniProgramList={onChangeMiniProgramList}
      />
    </PageContainer>
  );
};

export default connect(({ user }: ConnectState) => ({
  roleList: user.roleList,
}))(Club);
